@@ -72,8 +72,11 @@ class Interaction(object):
         for obj in ('request', 'response'):
             headers = self.data[obj]['headers']
             for k, v in list(headers.items()):
-                v = util.from_list(v)
-                headers[k] = v.replace(text_to_replace, placeholder)
+                if isinstance(v, list):
+                    headers[k] = [hv.replace(text_to_replace, placeholder)
+                                  for hv in v]
+                else:
+                    headers[k] = v.replace(text_to_replace, placeholder)
 
     def replace_in_body(self, text_to_replace, placeholder):
         for obj in ('request', 'response'):
